/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.DurativeActionEffectCompletionItemProvider = void 0;
const vscode_1 = require("vscode");
const pddl_workspace_1 = require("pddl-workspace");
const pddl_workspace_2 = require("pddl-workspace");
const AbstractCompletionItemProvider_1 = require("./AbstractCompletionItemProvider");
const DomainCompletionItemProvider_1 = require("./DomainCompletionItemProvider");
class DurativeActionEffectCompletionItemProvider extends AbstractCompletionItemProvider_1.AbstractCompletionItemProvider {
    constructor() {
        super();
        const requiresDurativeActions = DomainCompletionItemProvider_1.requires([':durative-actions']);
        this.addSuggestionDocumentation('at start', 'At start effect', new vscode_1.MarkdownString('Effect that takes place at the *start* point of a durative action. Only use this inside a `:durative-action`.')
            .appendCodeblock('(:durative-action\n:condition (and (at start (...) ) )\n:effect (and (at start (...) ) ) \n)', pddl_workspace_1.PDDL)
            .appendMarkdown(requiresDurativeActions), vscode_1.CompletionItemKind.Property);
        this.addSuggestionDocumentation('at end', 'At end effect', new vscode_1.MarkdownString('Effect that takes place at the *end* point of a durative action. Only use this inside a `:durative-action`.')
            .appendCodeblock('(:durative-action\n:condition (and (at end (...) ) )\n:effect (and (at end (...) ) ) \n)', pddl_workspace_1.PDDL)
            .appendMarkdown(requiresDurativeActions), vscode_1.CompletionItemKind.Property);
    }
    static inside(currentNode) {
        return pddl_workspace_2.ModelHierarchy.isInsideEffect(currentNode)
            && pddl_workspace_2.ModelHierarchy.isInsideDurativeActionUnqualifiedEffect(currentNode);
    }
    provide(_domainInfo, context, range) {
        if (context.triggerKind !== vscode_1.CompletionTriggerKind.Invoke && context.triggerCharacter !== '(') {
            return [];
        }
        return [
            this.createSnippetCompletionItem(AbstractCompletionItemProvider_1.Suggestion.from("at start", context.triggerCharacter, '('), "(at start $0)", range, context, 1),
            this.createSnippetCompletionItem(AbstractCompletionItemProvider_1.Suggestion.from("at end", context.triggerCharacter, '('), "(at end $0)", range, context, 2)
        ];
    }
}
exports.DurativeActionEffectCompletionItemProvider = DurativeActionEffectCompletionItemProvider;
//# sourceMappingURL=DurativeActionEffectCompletionItemProvider.js.map