/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.PddlCompletionItemProvider = void 0;
const pddl_workspace_1 = require("pddl-workspace");
const pddl_workspace_2 = require("pddl-workspace");
const pddl_workspace_3 = require("pddl-workspace");
const DomainCompletionItemProvider_1 = require("./DomainCompletionItemProvider");
const ProblemCompletionItemProvider_1 = require("./ProblemCompletionItemProvider");
const UnknownPddlCompletionItemProvider_1 = require("./UnknownPddlCompletionItemProvider");
class PddlCompletionItemProvider {
    // For snippet syntax read this: https://code.visualstudio.com/docs/editor/userdefinedsnippets
    constructor(codePddlWorkspace) {
        this.codePddlWorkspace = codePddlWorkspace;
    }
    async provideCompletionItems(document, position, token, context) {
        var _a;
        if (token.isCancellationRequested) {
            return undefined;
        }
        const fileInfo = await ((_a = this.codePddlWorkspace) === null || _a === void 0 ? void 0 : _a.upsertAndParseFile(document));
        if (fileInfo instanceof pddl_workspace_3.DomainInfo) {
            return await this.getOrCreateDomainCompletionItemProvider().provide(document, fileInfo, position, context);
        }
        else if (fileInfo instanceof pddl_workspace_2.ProblemInfo) {
            return await this.getOrCreateProblemCompletionItemProvider().provide(document, fileInfo, position, context);
        }
        else if (fileInfo instanceof pddl_workspace_1.UnknownFileInfo || fileInfo === null) {
            return await this.getOrCreateUnknownFileItemProvider().provide(document, position, context);
        }
        return [];
    }
    getOrCreateDomainCompletionItemProvider() {
        var _a;
        return (_a = this.domainProvider) !== null && _a !== void 0 ? _a : (this.domainProvider = new DomainCompletionItemProvider_1.DomainCompletionItemProvider());
    }
    getOrCreateProblemCompletionItemProvider() {
        var _a;
        return (_a = this.problemProvider) !== null && _a !== void 0 ? _a : (this.problemProvider = new ProblemCompletionItemProvider_1.ProblemCompletionItemProvider());
    }
    getOrCreateUnknownFileItemProvider() {
        var _a;
        return (_a = this.unknownProvider) !== null && _a !== void 0 ? _a : (this.unknownProvider = new UnknownPddlCompletionItemProvider_1.UnknownPddlCompletionItemProvider());
    }
}
exports.PddlCompletionItemProvider = PddlCompletionItemProvider;
//# sourceMappingURL=PddlCompletionItemProvider.js.map