/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnknownPddlCompletionItemProvider = void 0;
const vscode_1 = require("vscode");
const pddl_workspace_1 = require("pddl-workspace");
const utils_1 = require("../utils");
class UnknownPddlCompletionItemProvider {
    provide(document, position, _context) {
        const tree = new pddl_workspace_1.parser.PddlSyntaxTreeBuilder(document.getText()).getTree();
        const currentNode = tree.getNodeAt(document.offsetAt(position));
        const currentNodeParent = currentNode.getParent();
        if (currentNode.isDocument() ||
            currentNode.isType(pddl_workspace_1.parser.PddlTokenType.Whitespace) &&
                currentNodeParent && currentNodeParent.isDocument()) {
            const domainSnippet = new vscode_1.CompletionItem("domain", vscode_1.CompletionItemKind.Module);
            domainSnippet.command = { command: 'editor.action.insertSnippet', arguments: [{ 'langId': pddl_workspace_1.PDDL, 'name': 'domain' }], title: 'Insert domain snippet' };
            const problemSnippet = new vscode_1.CompletionItem("problem", vscode_1.CompletionItemKind.Module);
            problemSnippet.command = { command: 'editor.action.insertSnippet', arguments: [{ 'langId': pddl_workspace_1.PDDL, 'name': 'problem' }], title: 'Insert problem snippet' };
            return [
                domainSnippet,
                problemSnippet
            ];
        }
        else if (_context.triggerCharacter === '(') {
            if (currentNodeParent &&
                currentNodeParent.isType(pddl_workspace_1.parser.PddlTokenType.Document)) {
                const domainSnippet = new vscode_1.CompletionItem("(define domain...", vscode_1.CompletionItemKind.Module);
                domainSnippet.command = { command: 'editor.action.insertSnippet', arguments: [{ 'langId': pddl_workspace_1.PDDL, 'name': 'domain' }], title: 'Insert domain snippet' };
                domainSnippet.range = utils_1.nodeToRange(document, currentNode.expand());
                domainSnippet.insertText = '';
                domainSnippet.filterText = '(define domain';
                const problemSnippet = new vscode_1.CompletionItem("(define problem...", vscode_1.CompletionItemKind.Module);
                problemSnippet.command = { command: 'editor.action.insertSnippet', arguments: [{ 'langId': pddl_workspace_1.PDDL, 'name': 'problem' }], title: 'Insert problem snippet' };
                problemSnippet.range = utils_1.nodeToRange(document, currentNode.expand());
                problemSnippet.insertText = '';
                problemSnippet.filterText = '(define problem';
                return [
                    domainSnippet,
                    problemSnippet
                ];
            }
        }
        return [];
    }
}
exports.UnknownPddlCompletionItemProvider = UnknownPddlCompletionItemProvider;
//# sourceMappingURL=UnknownPddlCompletionItemProvider.js.map