/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.Validator = void 0;
const vscode_1 = require("vscode");
class Validator {
    constructor(path) {
        this.path = path;
    }
    createEmptyDiagnostics(domainInfo, problemFiles) {
        const diagnostics = new Map();
        diagnostics.set(domainInfo.fileUri.toString(), []);
        problemFiles.forEach(p => diagnostics.set(p.fileUri.toString(), []));
        return diagnostics;
    }
    static toSeverity(severity) {
        switch (severity.toLowerCase()) {
            case "error":
                return vscode_1.DiagnosticSeverity.Error;
            case "warning":
                return vscode_1.DiagnosticSeverity.Warning;
            case "info":
                return vscode_1.DiagnosticSeverity.Information;
            default:
                return vscode_1.DiagnosticSeverity.Hint;
        }
    }
    static createRange(line, character) {
        const position = new vscode_1.Position(line, character);
        return new vscode_1.Range(position, position);
    }
    static createLineRange(line) {
        return new vscode_1.Range(new vscode_1.Position(line, 0), new vscode_1.Position(line, Number.MAX_VALUE));
    }
}
exports.Validator = Validator;
//# sourceMappingURL=validator.js.map