/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi 2020. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.toDiagnostics = exports.toDiagnosticsFromParsingProblems = exports.createDiagnosticFromParsingProblem = exports.createDiagnostic = exports.createRangeFromLine = void 0;
const vscode_1 = require("vscode");
const utils_1 = require("../utils");
function createRangeFromLine(errorLine, errorColumn = 0) {
    return new vscode_1.Range(errorLine, errorColumn, errorLine, errorColumn + 100);
}
exports.createRangeFromLine = createRangeFromLine;
function createDiagnostic(errorLine, errorColumn, error, severity) {
    return new vscode_1.Diagnostic(createRangeFromLine(errorLine, errorColumn), error, severity);
}
exports.createDiagnostic = createDiagnostic;
function toDiagnosticSeverity(severity) {
    switch (severity) {
        case "error":
            return vscode_1.DiagnosticSeverity.Error;
        case "warning":
            return vscode_1.DiagnosticSeverity.Warning;
        case "info":
            return vscode_1.DiagnosticSeverity.Information;
        case "hint":
            return vscode_1.DiagnosticSeverity.Hint;
        default:
            throw new Error("Unexpected severity: " + severity);
    }
}
function createDiagnosticFromParsingProblem(problem) {
    return new vscode_1.Diagnostic(utils_1.toRange(problem.range), problem.problem, toDiagnosticSeverity(problem.severity));
}
exports.createDiagnosticFromParsingProblem = createDiagnosticFromParsingProblem;
function toDiagnosticsFromParsingProblems(problems) {
    return problems.map(p => createDiagnosticFromParsingProblem(p));
}
exports.toDiagnosticsFromParsingProblems = toDiagnosticsFromParsingProblems;
function toDiagnostics(parsingErrors, allParsed) {
    const diagnostics = new Map();
    parsingErrors.forEach((problems, uri) => diagnostics.set(uri, toDiagnosticsFromParsingProblems(problems)));
    // add empty diagnostic lists for files that are deemed valid (to make sure the previously identified issues are cleared from the UI)
    allParsed
        .filter(file => !diagnostics.has(file.fileUri.toString()))
        .forEach(validFile => diagnostics.set(validFile.fileUri.toString(), []));
    return diagnostics;
}
exports.toDiagnostics = toDiagnostics;
//# sourceMappingURL=validatorUtils.js.map