/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.DomainViewPanel = void 0;
const vscode_1 = require("vscode");
const BaseViewPanel_1 = require("./BaseViewPanel");
class DomainViewPanel extends BaseViewPanel_1.BaseViewPanel {
    constructor(uri, panel) {
        super(uri, panel);
        this.needsRebuild = false;
    }
    setDomain(domain) {
        this.domain = domain;
        this.error = undefined;
        this.setNeedsRebuild(true);
    }
    setError(ex) {
        this.error = ex;
    }
    getError() {
        return this.error;
    }
    getDomain() {
        if (!this.domain) {
            throw new Error(`Check if the panel was initialized by calling 'isInitialized' first.`);
        }
        return this.domain;
    }
    reveal(displayColumn) {
        this.panel.reveal(displayColumn !== null && displayColumn !== void 0 ? displayColumn : vscode_1.ViewColumn.Beside);
    }
    close() {
        this.panel.dispose();
    }
    setNeedsRebuild(needsRebuild) {
        this.needsRebuild = needsRebuild;
    }
    getNeedsRebuild() {
        return this.needsRebuild;
    }
    getPanel() {
        return this.panel;
    }
}
exports.DomainViewPanel = DomainViewPanel;
//# sourceMappingURL=DomainViewPanel.js.map