/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlanReportSettings = void 0;
const vscode_1 = require("vscode");
const workspaceFs_1 = require("../util/workspaceFs");
// todo: replace by JsonDomainVisualizationConfiguration
class PlanReportSettings {
    constructor(settings) {
        this.settings = settings;
    }
    static toVisualizationSettings(domainFileUri) {
        return vscode_1.Uri.file(domainFileUri.fsPath.replace(/\.pddl$/, '.planviz.json'));
    }
    static async load(domainFileUri) {
        const configurationFileUri = PlanReportSettings.toVisualizationSettings(domainFileUri);
        if (await workspaceFs_1.exists(configurationFileUri)) {
            const configurationText = (await vscode_1.workspace.fs.readFile(configurationFileUri)).toString();
            return this.loadFromText(configurationText);
        }
        else {
            return new PlanReportSettings(undefined);
        }
    }
    static loadFromText(configurationText) {
        try {
            const configuration = JSON.parse(configurationText);
            return new PlanReportSettings(configuration);
        }
        catch (err) {
            console.log(err);
            return new PlanReportSettings(undefined);
        }
    }
    shouldDisplay(planStep) {
        if (!this.settings) {
            return true;
        }
        if (this.excludeActions === undefined) {
            this.excludeActions = this.settings.excludeActions;
        }
        if (!this.excludeActions) {
            return true;
        }
        return !this.excludeActions.some(pattern => this.matches(pattern, planStep.getActionName()));
    }
    shouldIgnoreActionParameter(actionName, parameterName) {
        if (!this.settings) {
            return false;
        }
        if (this.ignoreActionParameters === undefined) {
            this.ignoreActionParameters = this.settings["ignoreActionParameters"];
        }
        if (!this.ignoreActionParameters) {
            return false;
        }
        const applicableSetting = this.ignoreActionParameters.find(entry => this.matches(entry.action, actionName));
        if (!applicableSetting) {
            return false;
        }
        return parameterName.match(new RegExp(applicableSetting.parameterPattern, "i")) !== null;
    }
    matches(pattern, actionName) {
        return !!actionName.match(new RegExp(pattern, "i"));
    }
    getPlanVisualizerScript() {
        var _a;
        return (_a = this.settings) === null || _a === void 0 ? void 0 : _a.customVisualization;
    }
}
exports.PlanReportSettings = PlanReportSettings;
//# sourceMappingURL=PlanReportSettings.js.map