/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi 2021. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerPlanReport = void 0;
const vscode_1 = require("vscode");
const vscode_extension_telemetry_wrapper_1 = require("vscode-extension-telemetry-wrapper");
const configuration_1 = require("../configuration/configuration");
const PlanView_1 = require("../planView/PlanView");
const utils_1 = require("../utils");
const PlanReportGenerator_1 = require("./PlanReportGenerator");
function registerPlanReport(context) {
    context.subscriptions.push(vscode_extension_telemetry_wrapper_1.instrumentOperationAsVsCodeCommand(PlanView_1.PDDL_GENERATE_PLAN_REPORT, async (plans, selectedPlan) => {
        if (plans) {
            const width = vscode_1.workspace.getConfiguration(configuration_1.CONF_PDDL).get(configuration_1.PLAN_REPORT_EXPORT_WIDTH, 1000);
            try {
                await new PlanReportGenerator_1.PlanReportGenerator(context, { displayWidth: width, selfContained: true }).export(plans, selectedPlan);
            }
            catch (ex) {
                utils_1.showError(ex);
            }
        }
        else {
            vscode_1.window.showErrorMessage("There is no plan to export.");
        }
    }));
}
exports.registerPlanReport = registerPlanReport;
//# sourceMappingURL=planReport.js.map