/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.exportToAndShow = void 0;
const vscode_1 = require("vscode");
const pddl_workspace_1 = require("pddl-workspace");
async function exportToAndShow(text, uri) {
    const fileExists = await pddl_workspace_1.utils.afs.exists(uri.fsPath);
    if (!fileExists) {
        uri = uri.with({ scheme: 'untitled' });
    }
    const newDocument = await vscode_1.workspace.openTextDocument(uri);
    const editor = await vscode_1.window.showTextDocument(newDocument, { viewColumn: vscode_1.ViewColumn.Active, preserveFocus: true });
    const fullRange = newDocument.validateRange(new vscode_1.Range(0, 0, newDocument.lineCount, 0));
    if (await editor.edit(edit => edit.replace(fullRange, text))) {
        return newDocument.save();
    }
    else {
        throw new Error("Cannot insert text to document: " + newDocument.fileName);
    }
}
exports.exportToAndShow = exportToAndShow;
//# sourceMappingURL=ExportUtil.js.map