"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlannerUserOptionsSelector = void 0;
/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
const vscode = require("vscode");
class PlannerUserOptionsSelector {
    constructor() {
        this.NO_OPTIONS = { label: 'No options (use defaults)', options: '', description: '' };
        this.optionsHistory = [this.NO_OPTIONS, { label: 'Specify options...', newValue: true, options: '', description: '' }];
    }
    async getPlannerOptions(plannerProvider) {
        var _a, _b;
        let builtInOptions;
        if (plannerProvider === null || plannerProvider === void 0 ? void 0 : plannerProvider.getPlannerOptions) {
            builtInOptions = (_b = (_a = plannerProvider === null || plannerProvider === void 0 ? void 0 : plannerProvider.getPlannerOptions()) === null || _a === void 0 ? void 0 : _a.map(option => this.toOptionsQuickPickItem(option))) !== null && _b !== void 0 ? _b : [];
        }
        else {
            builtInOptions = [];
        }
        let optionsSelected = await vscode.window.showQuickPick(this.optionsHistory.concat(builtInOptions), { placeHolder: 'Optionally specify planner switches or press ENTER to use default planner configuration.', ignoreFocusOut: true });
        if (!optionsSelected) {
            return undefined;
        } // operation canceled by the user by pressing Escape
        else if (optionsSelected.newValue) {
            const optionsEntered = await vscode.window.showInputBox({ placeHolder: 'Specify planner options.' });
            if (!optionsEntered) {
                return undefined;
            }
            optionsSelected = { label: optionsEntered, options: optionsEntered, description: '' };
        }
        else if (optionsSelected !== this.NO_OPTIONS) {
            // a previous option was selected - lets allow the user to edit it before continuing
            const optionsEntered = await vscode.window.showInputBox({ value: optionsSelected.options, placeHolder: 'Specify planner options.', prompt: 'Adjust the options, if needed and press Enter to continue.' });
            if (!optionsEntered) {
                return undefined;
            } // canceled by the user
            optionsSelected = { label: optionsEntered, options: optionsEntered, description: '' };
        }
        const indexOf = this.optionsHistory.findIndex(option => option.options === optionsSelected.options);
        if (indexOf > -1) {
            this.optionsHistory.splice(indexOf, 1);
        }
        this.optionsHistory.unshift(optionsSelected); // insert to the first position
        return optionsSelected.options;
    }
    toOptionsQuickPickItem(option) {
        var _a, _b;
        return {
            label: (_a = option.label) !== null && _a !== void 0 ? _a : option.option,
            options: option.option,
            description: (_b = option.description) !== null && _b !== void 0 ? _b : ''
        };
    }
}
exports.PlannerUserOptionsSelector = PlannerUserOptionsSelector;
//# sourceMappingURL=PlannerUserOptionsSelector.js.map