/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlanningResult = exports.PlanningOutcome = void 0;
var PlanningOutcome;
(function (PlanningOutcome) {
    PlanningOutcome[PlanningOutcome["SUCCESS"] = 0] = "SUCCESS";
    PlanningOutcome[PlanningOutcome["FAILURE"] = 1] = "FAILURE";
    PlanningOutcome[PlanningOutcome["KILLED"] = 2] = "KILLED";
})(PlanningOutcome = exports.PlanningOutcome || (exports.PlanningOutcome = {}));
/**
 * Outcome of the planner execution.
 */
class PlanningResult {
    constructor(outcome, plans, elapsedTime, error) {
        this.outcome = outcome;
        this.plans = plans;
        this.elapsedTime = elapsedTime;
        this.error = error;
    }
    /**
     * Creates the result instance for the case of successful planner execution.
     * @param plans plans
     */
    static success(plans, elapsedTime) {
        return new PlanningResult(PlanningOutcome.SUCCESS, plans, elapsedTime, undefined);
    }
    /**
     * Creates the result instance for the case of planner failure.
     * @param error error
     */
    static failure(error) {
        return new PlanningResult(PlanningOutcome.FAILURE, [], Number.NaN, error);
    }
    /**
     * Creates the result instance for the case of planner killed by the user.
     */
    static killed() {
        return new PlanningResult(PlanningOutcome.KILLED, [], Number.NaN, undefined);
    }
}
exports.PlanningResult = PlanningResult;
//# sourceMappingURL=PlanningResult.js.map