/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.MockSearch = void 0;
const request = require("request");
const utils_1 = require("../utils");
const pddl_workspace_1 = require("pddl-workspace");
const configuration_1 = require("../configuration/configuration");
class MockSearch {
    constructor(port) {
        /**
         * the `patch` method will be useful when the contract migrates `patch` HTTP verb.
         */
        // private async patch(path: string, content: any): Promise<void> {
        //     return await new Promise<void>((resolve, reject) => {
        //         request.patch(this.url + path, { json: content }, (error, httpResponse, _httpBody) => {
        //             if (error) {
        //                 reject(error);
        //             }
        //             else {
        //                 if (httpResponse && httpResponse.statusCode > 204) {
        //                     reject('HTTP status code ' + httpResponse.statusCode);
        //                 }
        //                 else {
        //                     resolve(void 0);
        //                 }
        //             }
        //         });
        //     });
        // }
        this.state0 = undefined;
        this.state0_0 = undefined;
        this.state0_1 = undefined;
        this.state0_0_0 = undefined;
        this.state0_0_1 = undefined;
        this.state0_1_0 = undefined;
        this.state0_1_1 = undefined;
        this.state0_1_0_0 = undefined;
        this.state0_1_0_0_0 = undefined;
        this.events = [
            new MockStateContextEvent("post-initial", this.state0 = MockStateContext.createInitial()),
            new MockStateSearchContextEvent("patch", this.state0.evaluate(5, [MockHelpfulAction.start("drive"), MockHelpfulAction.start("load")], state => state.buildRelaxedPlan().start("drive").start("load").end(1, "load").end(3, "drive"))),
            new MockStateContextEvent("post", this.state0_0 = this.state0.applyStart("drive", 0)),
            new MockStateContextEvent("post", this.state0_1 = this.state0.applyStart("load", 0)),
            new MockStateSearchContextEvent("patch", this.state0_0.evaluate(5, [MockHelpfulAction.start("load"), MockHelpfulAction.end("drive")], state => state.buildRelaxedPlan().end(4, "drive").start("load").end(1, "load"))),
            new MockStateSearchContextEvent("patch", this.state0_1.evaluate(4, [MockHelpfulAction.start("drive"), MockHelpfulAction.end("load")], state => state.buildRelaxedPlan().end(1, "load").start("drive").end(4, "drive"))),
            new MockStateContextEvent("post", this.state0_0_0 = this.state0_0.applyEnd("drive", 0, 3)),
            new MockStateContextEvent("post", this.state0_0_1 = this.state0_0.applyStart("load", 0)),
            new MockStateSearchContextEvent("patch", this.state0_0_0.evaluate(4, [MockHelpfulAction.start("load")], state => state.buildRelaxedPlan().start("load").end(1, "load"))),
            new MockStateSearchContextEvent("patch", this.state0_0_1.evaluate(3, [MockHelpfulAction.end("load"), MockHelpfulAction.end("drive")], state => state.buildRelaxedPlan().end(4, "drive").end(1, "load"))),
            new MockStateContextEvent("post", this.state0_1_0 = this.state0_1.applyEnd("load", 0, .5)),
            new MockStateContextEvent("post", this.state0_1_1 = this.state0_1.applyStart("drive", 0)),
            new MockStateSearchContextEvent("patch", this.state0_1_0.evaluate(2, [MockHelpfulAction.start("drive")], state => state.buildRelaxedPlan().start("drive").end(4, "drive"))),
            new MockStateSearchContextEvent("patch", this.state0_1_1.evaluate(3, [MockHelpfulAction.end("drive"), MockHelpfulAction.end("load")], state => state.buildRelaxedPlan().end(4, "drive").end(1, "load"))),
            new MockStateContextEvent("post", this.state0_1_0_0 = this.state0_1_0.applyStart("drive", 0)),
            new MockStateSearchContextEvent("patch", this.state0_1_0_0.evaluate(1, [MockHelpfulAction.end("drive")], state => state.buildRelaxedPlan().end(4, "drive"))),
            new MockStateContextEvent("post", this.state0_1_0_0_0 = this.state0_1_0_0.applyEnd("drive", 0, 4)),
            new MockStateSearchContextEvent("patch", this.state0_1_0_0_0.evaluate(0, [], state => state.buildRelaxedPlan())),
        ];
        this.url = `http://localhost:${port}`;
    }
    async run() {
        const helloWorld = await new Promise((resolve, reject) => {
            request.get(this.url + '/about', (error, httpResponse, httpBody) => {
                if (error) {
                    reject(error);
                    return;
                }
                else {
                    if (httpResponse && httpResponse.statusCode > 204) {
                        reject("HTTP status code " + httpResponse.statusCode);
                        return;
                    }
                    else {
                        resolve(httpBody);
                    }
                }
            });
        });
        console.log(helloWorld);
        for (const mockEvent of this.events) {
            console.log("sending mock event: ");
            console.log(mockEvent);
            await utils_1.sleep(100);
            try {
                await this.send(mockEvent);
            }
            catch (ex) {
                console.log(ex);
                break;
            }
        }
        console.log('Mock-search finished.');
    }
    async send(mockEvent) {
        switch (mockEvent.operation) {
            case 'post-initial':
                return await this.post('/state/initial', mockEvent.toWireMessage());
            case 'post':
                return await this.post('/state', mockEvent.toWireMessage());
            case 'patch':
                // this should really be a 'patch' verb, but the clients have more trouble making it work
                return await this.post('/state/heuristic', mockEvent.toWireMessage());
            default:
                console.log("Unsupported mock event: " + mockEvent.operation);
        }
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    async post(path, content) {
        return await new Promise((resolve, reject) => {
            request.post(this.url + path, { json: content }, (error, httpResponse) => {
                if (error) {
                    reject(error);
                    return;
                }
                else {
                    if (httpResponse && httpResponse.statusCode > 204) {
                        reject('HTTP status code ' + httpResponse.statusCode);
                        return;
                    }
                    else {
                        resolve(void 0);
                    }
                }
            });
        });
    }
}
exports.MockSearch = MockSearch;
class MockEvent {
    constructor(operation) {
        this.operation = operation;
    }
}
class MockStateContextEvent extends MockEvent {
    constructor(operation, stateContext) {
        super(operation);
        this.operation = operation;
        this.stateContext = stateContext;
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    toWireMessage() {
        return {
            id: this.stateContext.state.id,
            parentId: this.stateContext.parentId,
            g: this.stateContext.g,
            earliestTime: this.stateContext.earliestTime,
            appliedAction: this.stateContext.appliedAction ? toWireSearchHappening(this.stateContext.appliedAction) : null,
            planHead: this.stateContext.planHead.map(h => toWireSearchHappening(h))
        };
    }
}
class MockStateSearchContextEvent extends MockEvent {
    constructor(operation, stateSearchContext) {
        super(operation);
        this.operation = operation;
        this.stateSearchContext = stateSearchContext;
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    toWireMessage() {
        return {
            id: this.stateSearchContext.stateContext.state.id,
            totalMakespan: this.stateSearchContext.totalMakespan,
            h: this.stateSearchContext.h,
            helpfulActions: this.stateSearchContext.helpfulActions.map(a => toWireHelpfulAction(a)),
            relaxedPlan: this.stateSearchContext.relaxedPlan.map(h => toWireSearchHappening(h))
        };
    }
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function toWireSearchHappening(happening) {
    return {
        earliestTime: happening.earliestTime,
        actionName: happening.actionName,
        shotCounter: happening.shotCounter,
        kind: pddl_workspace_1.HappeningType[happening.kind]
    };
}
// eslint-disable-next-line @typescript-eslint/no-explicit-any
function toWireHelpfulAction(action) {
    return {
        actionName: action.actionName,
        kind: pddl_workspace_1.HappeningType[action.kind]
    };
}
class MockStateSearchContext {
    constructor(stateContext, totalMakespan, h, helpfulActions, relaxedPlan) {
        this.stateContext = stateContext;
        this.totalMakespan = totalMakespan;
        this.h = h;
        this.helpfulActions = helpfulActions;
        this.relaxedPlan = relaxedPlan;
    }
}
class MockStateContext {
    constructor(state, g, earliestTime, appliedAction, planHead, parentId) {
        this.state = state;
        this.g = g;
        this.earliestTime = earliestTime;
        this.appliedAction = appliedAction;
        this.planHead = planHead;
        this.parentId = parentId;
    }
    static createInitial() {
        return new MockStateContext(MockState.createInitial(), 0, EPSILON, undefined, [], undefined);
    }
    get actionName() {
        var _a;
        return (_a = this.appliedAction) === null || _a === void 0 ? void 0 : _a.actionName;
    }
    isInitialState() {
        return this.planHead.length === 0;
    }
    getLastHappening() {
        if (this.isInitialState()) {
            throw new Error("Check if this is an initial state first..");
        }
        return this.planHead[this.planHead.length - 1];
    }
    applyStart(actionName, shotCounter) {
        return this.apply(actionName, shotCounter, pddl_workspace_1.HappeningType.START, EPSILON);
    }
    applyEnd(actionName, shotCounter, duration) {
        return this.apply(actionName, shotCounter, pddl_workspace_1.HappeningType.END, duration);
    }
    apply(actionName, shotCounter, kind, timeIncrement) {
        const id = ++MockState.lastStateId;
        const earliestTime = this.earliestTime + timeIncrement;
        const appliedAction = new MockSearchHappening(earliestTime, actionName, shotCounter, 1, kind, false);
        const newPlanHead = this.planHead.concat([appliedAction]);
        return new MockStateContext(new MockState(id.toString()), this.g + 1, earliestTime, appliedAction, newPlanHead, this.state.id);
    }
    evaluate(h, helpfulActions, relaxedPlanFactory) {
        const relaxedStateBuilder = relaxedPlanFactory(this);
        const relaxedPlan = relaxedStateBuilder.build();
        const totalMakespan = relaxedPlan.length ? Math.max(...relaxedPlan.map(step => step.earliestTime)) : this.earliestTime;
        const newState = new MockStateSearchContext(this, totalMakespan, h, helpfulActions, relaxedPlan);
        return newState;
    }
    buildRelaxedPlan() {
        return new RelaxedPlanBuilder(this.earliestTime);
    }
    toString() {
        return `State={id: ${this.state.id}, G: ${this.g}}`;
    }
}
class MockState {
    constructor(id) {
        this.id = id;
    }
    static createInitial() {
        const id = ++this.lastStateId;
        return new MockState(id.toString());
    }
}
MockState.lastStateId = -1;
const EPSILON = configuration_1.DEFAULT_EPSILON;
class RelaxedPlanBuilder {
    constructor(earliestStateTime) {
        this.earliestStateTime = earliestStateTime;
        this.happenings = [];
        this.time = this.earliestStateTime;
    }
    start(actionName) {
        const time = this.time += EPSILON;
        this.happenings.push(new MockSearchHappening(time, actionName, 0, 1, pddl_workspace_1.HappeningType.START, true));
        return this;
    }
    end(timeOffset, actionName) {
        const time = this.time += timeOffset;
        this.happenings.push(new MockSearchHappening(time, actionName, 0, 1, pddl_workspace_1.HappeningType.END, true));
        return this;
    }
    build() {
        return this.happenings;
    }
}
class MockSearchHappening {
    constructor(earliestTime, actionName, shotCounter, iterations, kind, isRelaxed) {
        this.earliestTime = earliestTime;
        this.actionName = actionName;
        this.shotCounter = shotCounter;
        this.iterations = iterations;
        this.kind = kind;
        this.isRelaxed = isRelaxed;
    }
    toString() {
        const relaxed = this.isRelaxed ? '*' : '';
        const iterations = this.iterations > 1 ? ` ${this.iterations}x` : '';
        return `${this.earliestTime}: ${this.actionName}[${this.shotCounter}] ${this.kind}${relaxed}${iterations}`;
    }
}
class MockHelpfulAction {
    constructor(actionName, kind) {
        this.actionName = actionName;
        this.kind = kind;
    }
    static start(actionName) {
        return new MockHelpfulAction(actionName, pddl_workspace_1.HappeningType.START);
    }
    static end(actionName) {
        return new MockHelpfulAction(actionName, pddl_workspace_1.HappeningType.END);
    }
}
//# sourceMappingURL=MockSearch.js.map