"use strict";
/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
Object.defineProperty(exports, "__esModule", { value: true });
exports.saveConfiguration = exports.readSessionConfiguration = exports.isSessionFolder = exports.toSessionConfiguration = exports.SessionMode = exports.CONFIGURATION_FILE = void 0;
const vscode_1 = require("vscode");
const pddl_workspace_1 = require("pddl-workspace");
const workspaceFs_1 = require("../util/workspaceFs");
exports.CONFIGURATION_FILE = '.planning.domains.session.json';
var SessionMode;
(function (SessionMode) {
    SessionMode[SessionMode["READ_ONLY"] = 0] = "READ_ONLY";
    SessionMode[SessionMode["READ_WRITE"] = 1] = "READ_WRITE";
})(SessionMode = exports.SessionMode || (exports.SessionMode = {}));
function toSessionConfiguration(id, mode) {
    let sessionConfiguration;
    switch (mode) {
        case SessionMode.READ_ONLY:
            sessionConfiguration = { hash: id };
            break;
        case SessionMode.READ_WRITE:
            sessionConfiguration = { writeHash: id };
            break;
    }
    return sessionConfiguration;
}
exports.toSessionConfiguration = toSessionConfiguration;
function toConfigurationFileUri(folder) {
    return vscode_1.Uri.joinPath(folder.uri, exports.CONFIGURATION_FILE);
}
async function isSessionFolder(folder) {
    const configurationUri = toConfigurationFileUri(folder);
    return workspaceFs_1.exists(configurationUri);
}
exports.isSessionFolder = isSessionFolder;
async function readSessionConfiguration(folder) {
    const configurationPath = toConfigurationFileUri(folder);
    const data = await vscode_1.workspace.fs.readFile(configurationPath);
    return JSON.parse(data.toString(), (key, value) => {
        if (key === "files") {
            return pddl_workspace_1.utils.serializationUtils.objToStrMap(value);
        }
        else if (key === "versionDate") {
            return Date.parse(value);
        }
        else {
            return value;
        }
    });
}
exports.readSessionConfiguration = readSessionConfiguration;
async function saveConfiguration(workspaceFolderUri, sessionConfiguration) {
    const sessionConfigurationString = JSON.stringify(sessionConfiguration, (name, val) => {
        if (name === "files") {
            return pddl_workspace_1.utils.serializationUtils.strMapToObj(val);
        }
        else if (name === "versionDate") {
            return new Date(val).toISOString();
        }
        else {
            return val;
        }
    }, 4);
    return vscode_1.workspace.fs.writeFile(vscode_1.Uri.joinPath(workspaceFolderUri, exports.CONFIGURATION_FILE), Buffer.from(sessionConfigurationString, 'utf8'));
}
exports.saveConfiguration = saveConfiguration;
//# sourceMappingURL=SessionConfiguration.js.map