"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SessionUriHandler = void 0;
/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
const vscode_1 = require("vscode");
const SessionSourceControl_1 = require("./SessionSourceControl");
/** Handles system-wide URI requests. Note that each session can register only one UriHandler! */
class SessionUriHandler {
    constructor() {
        this.handlers = [
            new ReadOnlySessionUriHandler(),
            new ReadWriteSessionUriHandler()
        ];
    }
    handleUri(uri) {
        this.handlers
            .filter(h => h.matches(uri))
            .forEach(h => h.handle(uri));
    }
}
exports.SessionUriHandler = SessionUriHandler;
class SingleArgumentUriHandler {
    constructor(pattern, command) {
        this.pattern = pattern;
        this.command = command;
    }
    matches(uri) {
        this.pattern.lastIndex = 0;
        const matchGroups = this.pattern.exec(uri.path);
        return matchGroups !== null;
    }
    handle(uri) {
        this.pattern.lastIndex = 0;
        const matchGroups = this.pattern.exec(uri.path);
        if (matchGroups) {
            const argumentValue = matchGroups[1];
            vscode_1.commands.executeCommand(this.command, argumentValue);
        }
    }
}
class ReadOnlySessionUriHandler extends SingleArgumentUriHandler {
    constructor() {
        super(/\/planning.domains\/session\/(\w+)$/i, SessionSourceControl_1.SESSION_COMMAND_LOAD);
    }
}
class ReadWriteSessionUriHandler extends SingleArgumentUriHandler {
    constructor() {
        super(/\/planning.domains\/session\/edit\/(\w+)$/i, SessionSourceControl_1.SESSION_COMMAND_LOAD);
    }
}
//# sourceMappingURL=SessionUriHandler.js.map