/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.MissingRequirements = void 0;
const vscode_1 = require("vscode");
const pddl_workspace_1 = require("pddl-workspace");
const UndeclaredVariable_1 = require("./UndeclaredVariable");
class MissingRequirements {
    constructor(fileInfo) {
        this.syntaxTree = new pddl_workspace_1.parser.PddlSyntaxTreeBuilder(fileInfo.getText()).getTree();
    }
    getRequirementName(diagnosticMessage) {
        const match = MissingRequirements.undeclaredRequirementDiagnosticPattern.exec(diagnosticMessage);
        if (!match) {
            return undefined;
        }
        let requirementName = ':' + match[1];
        // todo: remove this when the parser is fixed
        if (requirementName === ':number-fluents') {
            requirementName = ':fluents';
        }
        return requirementName;
    }
    createEdit(document, requirementName) {
        const defineNode = this.syntaxTree.getDefineNode();
        const requirementsNode = defineNode.getFirstOpenBracket(':requirements');
        const edit = new vscode_1.WorkspaceEdit();
        if (requirementsNode) {
            edit.insert(document.uri, document.positionAt(requirementsNode.getEnd() - 1), ' ' + requirementName);
        }
        else {
            const domainNode = defineNode.getFirstOpenBracketOrThrow('domain');
            const indent = UndeclaredVariable_1.UndeclaredVariable.createIndent(document, 1);
            const eol = UndeclaredVariable_1.UndeclaredVariable.createEolString(document);
            edit.insert(document.uri, document.positionAt(domainNode.getEnd()), eol + indent + `(:requirements ${requirementName})`);
        }
        return edit;
    }
}
exports.MissingRequirements = MissingRequirements;
MissingRequirements.undeclaredRequirementDiagnosticPattern = /^undeclared requirement\s*:([\w-]+)/i;
//# sourceMappingURL=MissingRequirements.js.map