/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValDownloadReminder = void 0;
const vscode_1 = require("vscode");
const NEVER_DOWNLOAD_VAL = 'neverDownloadVal';
class ValDownloadReminder {
    constructor(context, val) {
        this.context = context;
        this.val = val;
        this.downloadValLater = false;
    }
    async suggestValDownloadConfigurationIfAbsent() {
        const isInstalled = await this.val.isInstalled();
        if (!isInstalled) {
            this.suggestValDownloadConfiguration(true);
        }
    }
    async suggestValDownloadConfiguration(showNever) {
        if (this.downloadValLater || this.context.globalState.get(NEVER_DOWNLOAD_VAL)) {
            return;
        }
        const downloadValNow = { title: "Download now..." };
        const downloadValNever = { title: "Never" };
        const downloadValLater = { title: "Later", isCloseAffordance: true };
        const options = [downloadValNow, downloadValLater];
        if (showNever) {
            options.splice(2, 0, downloadValNever);
        }
        const message = "To enable all features, get PDDL parser and plan validator and evaluator. Download the [build](https://dev.azure.com/schlumberger/ai-planning-validation) of [VAL tools](https://github.com/KCL-Planning/VAL).";
        const choice = await vscode_1.window.showInformationMessage(message, ...options);
        switch (choice) {
            case downloadValNow:
                this.launchDownload();
                // if the above method call updates the configuration, the parser will be notified
                break;
            case downloadValLater:
                this.downloadValLater = true; // will retry in the next session
                break;
            case downloadValNever:
                this.context.globalState.update(NEVER_DOWNLOAD_VAL, true);
                break;
            default:
                break;
        }
    }
    async launchDownload() {
        var _a;
        try {
            await this.val.downloadConfigureAndCleanUp();
        }
        catch (ex) {
            vscode_1.window.showErrorMessage((_a = ex.message) !== null && _a !== void 0 ? _a : ex);
        }
    }
}
exports.ValDownloadReminder = ValDownloadReminder;
//# sourceMappingURL=ValDownloadReminder.js.map