/* --------------------------------------------------------------------------------------------
 * Copyright (c) Jan Dolejsi. All rights reserved.
 * Licensed under the MIT License. See License.txt in the project root for license information.
 * ------------------------------------------------------------------------------------------ */
'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
exports.AssociationCodeActionProvider = void 0;
const vscode_1 = require("vscode");
const workspaceUtils_1 = require("./workspaceUtils");
const AssociationProvider_1 = require("./AssociationProvider");
/**
 * Provides code actions corresponding to diagnostic problems.
 */
class AssociationCodeActionProvider {
    provideCodeActions(document, _range, context, token) {
        //console.log('providing code lens actions');
        if (token.isCancellationRequested) {
            return [];
        }
        const associateProblemCodeActions = context.diagnostics
            .filter(diagnostic => diagnostic.code === workspaceUtils_1.NoProblemAssociated.DIAGNOSTIC_CODE)
            .map(diagnostic => this.createAssociateProblemCommand(diagnostic, document));
        const associateDomainCodeActions = context.diagnostics
            .filter(diagnostic => diagnostic.code === workspaceUtils_1.NoDomainAssociated.DIAGNOSTIC_CODE)
            .map(diagnostic => this.createAssociateDomainCommand(diagnostic, document));
        return associateProblemCodeActions.concat(associateDomainCodeActions);
    }
    createAssociateProblemCommand(diagnostic, document) {
        //console.log('creating association quick fix for ' + document.fileName);
        const title = 'Associate problem file that corresponds to this plan file...';
        const action = new vscode_1.CodeAction(title, vscode_1.CodeActionKind.QuickFix);
        action.command = { command: AssociationProvider_1.COMMAND_ASSOCIATE_PROBLEM, arguments: [document.uri], title: title };
        action.diagnostics = [diagnostic];
        action.isPreferred = true;
        return action;
    }
    createAssociateDomainCommand(diagnostic, document) {
        const title = 'Associate domain file that corresponds to this problem file...';
        const action = new vscode_1.CodeAction(title, vscode_1.CodeActionKind.QuickFix);
        action.command = { command: AssociationProvider_1.COMMAND_ASSOCIATE_DOMAIN, arguments: [document.uri], title: title };
        action.diagnostics = [diagnostic];
        action.isPreferred = true;
        return action;
    }
}
exports.AssociationCodeActionProvider = AssociationCodeActionProvider;
AssociationCodeActionProvider.providedCodeActionKinds = [
    vscode_1.CodeActionKind.QuickFix
];
//# sourceMappingURL=AssociationCodeActionProvider.js.map